#!/usr/bin/python3

import getopt
import json
import os
import sys
import time

import load
from functions import delete_outbound_acl
from functions import do_get
from functions import get_department_drs
from functions import get_employee_classification_drs
from functions import get_employee_drs
from functions import get_outbound_acls
from functions import get_token
from functions import get_zone
from functions import get_zone_adaptor
from functions import link_employee_drs
from functions import post_outbound_acl

assert sys.version_info >= (3, 7)

def usage():
    print("")
    print("Used by start.py to link colleges and students to enrollments")
    print("")

try:
    opts, _ = getopt.getopt(sys.argv[1:], "h")
except getopt.GetoptError as err:
    print("ERROR: " + err.msg + "\n")
    usage()
    sys.exit(1)

script_path = os.path.dirname(os.path.realpath(__file__))

global_file = script_path + "/../local_global.json"
namespace = "default"
auth_server_url = "http://younite-api:8080"

for o, _ in opts:
    if o == "-h":
        usage()
        sys.exit(0)

try:
    gf = open(global_file, "r")
    # Get the token
    json_global = json.load(gf)
    values = json_global.get("values")

    token_href = next((x.get("value") for x in values if x.get("key") == "token_href"), None)
    client_id = next((x.get("value") for x in values if x.get("key") == "client_id"), None)
    client_secret = next((x.get("value") for x in values if x.get("key") == "client_secret"), None)
    username = next((x.get("value") for x in values if x.get("key") == "dgs_username"), None)
    password = next((x.get("value") for x in values if x.get("key") == "dgs_password"), None)

    dgs_token = get_token(token_href, client_id, client_secret, username, password)
    if dgs_token is None:
        print("Either the YOUnite server is down or the credentials for the following user are invalid: dgs")
    href = next((x.get("value") for x in values if x.get("key") == "href"), None)

    print()
    print("=== LINK EMPLOYEE_CLASSIFICATION, DEPARTMENT AND MANAGER TO EMPLOYEES ===========================")
    print()

    # Get Asia Zone
    asia_zone_uuid = get_zone(href, dgs_token, 'Asia Headquarters')
    print ('asia_zone_uuid=',asia_zone_uuid)

    # Get Asia adaptor
    asia_adaptor_uuid = get_zone_adaptor(href, dgs_token, asia_zone_uuid, 'Asia Database - Postgres')["uuid"]
    print('asia_adaptor_uuid=', asia_adaptor_uuid)

    # Get Europe  Zone
    eu_zone_uuid = get_zone(href, dgs_token, 'Europe Headquarters')
    print('eu_zone_uuid=', eu_zone_uuid)

    print()
    print("=== LOAD DEPARTMENT AND EMPLOYEE DATA ==================================")
    print()

    print("Block data events from flowing out from Asia to the EU by Creating an Outbound ACL")
    print()
    response = post_outbound_acl(href, dgs_token,
                               asia_zone_uuid,
                               "00000000-0000-0000-0000-000000000000",
                               "00000000-0000-0000-0000-000000000000",
                               eu_zone_uuid,
                               "00000000-0000-0000-0000-000000000000",
                               False, True, True, True)
    print()

    # Load the Data
    load.load_data("1", script_path + "/../test-data/department_10.sql", post=False)
    load.load_data("1", script_path + "/../test-data/employee_10.sql", post=False)

    # Sleep to make sure all fo the data events load
    print()
    print("Check if last record was loaded.")
    while True:
        response = do_get(href + '/drs', dgs_token,
                          {"filters": "name:employee,version:1", "query": "employeeId:1E43673MAX"})
        if response and response.status_code == 200:
            payload_b = response.content.decode('utf8').replace("'", '"')
            payload_json = json.loads(payload_b)
            if len(payload_json['drs']) > 0:
                break
        print("z", end='', flush=True)
        time.sleep(1)
    print()

    print()
    print("Get Employees, employee_classifications and departments")
    # Get employee_map
    employee_map = get_employee_drs(href, dgs_token, asia_adaptor_uuid)
    # print(employee_map)

    # Get employee_classification_map
    employee_classification_map = get_employee_classification_drs(href, dgs_token)
    # print(employee_classification_map)

    # Get department_map
    department_map = get_department_drs(href, dgs_token, asia_adaptor_uuid)
    # print(department_map)

    # Link enrollments DRs
    print()
    print("Link Records")
    link_employee_drs(href, dgs_token, asia_zone_uuid, asia_adaptor_uuid, employee_map,  employee_classification_map, department_map)

    # Remove ACL
    response = get_outbound_acls(href, dgs_token, asia_zone_uuid)
    if response and response.content:
        acl_json = response.content.decode('utf8').replace("'", '"')
        data = json.loads(acl_json)
        acls = data['outboundAclEntries']
        for i in range(len(acls)):
            print()
            print("DELETEd Outbound ACL: " + (acls[i])['uuid'])
            print()
            delete_outbound_acl(href, dgs_token, asia_zone_uuid, (acls[i])['uuid'] )

finally:
    # remove temp files
    for f in os.listdir("."):
        if f.startswith("credentials-") and f.endswith(".json"):
            os.remove(f)

sys.exit(0)
