#!/usr/bin/python3

import json
import getopt
import os
import sys
from functions import __getToken, __getZone, getDomain, getDomainVersion, putDataNotificationRegistration

#
# Create a notification so that any new, updated or deleted transcript_requests will send a
# notification to a process maker task.
#
# Before running this make sure the YOUnite stack is running (locally or in AWS) and that the younite-api server is ready.
#
# To verify that the younite-api server is running, make a request to the /health endpoint from a browser.
#
# For example, if running locally:
#
# http://local.younite.org:8080/health
#

authorization = {}
authorization['name'] = "Authorization"
authorization['value'] = "Contact YOUnite - ask for: ProcessMaker Demo Account - PM Key"

assert sys.version_info >= (3, 7)

process_num = "9"
node_id = "node_8"
callback_url = "https://younite.pm4trial.processmaker.net/api/1.0/process_events/" + process_num + "?event=" + node_id

script_path = os.path.dirname(os.path.realpath(__file__))

global_file = script_path + "/../local_global.json"
try:
    gf = open(global_file, "r")
    json_global = json.load(gf)
    values = json_global.get("values")
    token_href = next((x.get("value") for x in values if x.get("key") == "token_href"), None)
    client_id = next((x.get("value") for x in values if x.get("key") == "client_id"), None)
    client_secret = next((x.get("value") for x in values if x.get("key") == "client_secret"), None)
    username = next((x.get("value") for x in values if x.get("key") == "dgs_username"), None)
    password = next((x.get("value") for x in values if x.get("key") == "dgs_password"), None)
    href = next((x.get("value") for x in values if x.get("key") == "href"), None)

    dgs_token = __getToken(token_href, client_id, client_secret, username, password)
    if dgs_token is None:
        print("Either the YOUnite server is down or the credentials for the following user are invalid: dgs")
        sys.exit(3)

    sending_zone = __getZone(href, dgs_token, "eTranscript CA")
    target_domain_uuid = getDomain(href, dgs_token, "transcriptRequest")
    target_domain_version_uuid = getDomainVersion (href, dgs_token, target_domain_uuid, "1")

    resource = "/zones/" + sending_zone + "/adaptors/?/domains/" + target_domain_uuid + "/versions/" + \
               target_domain_version_uuid + "/drs/?"


    event = {}
    event['resource'] = resource
    event['drEventType'] = "ORIGINATED"
    event['actions'] = ["PUT", "POST", "DELETE"]

    req_set = {}
    req_set['id'] = "transcript-request-notification"
    req_set['callback'] = callback_url
    req_set['httpHeaders'] = []
    (req_set['httpHeaders']).append(authorization)
    req_set['callbackType'] = "WEB_HOOK"
    req_set['events'] = []
    (req_set['events']).append(event)

    response = putDataNotificationRegistration(href, dgs_token, req_set)

finally:
    # remove temp files
    for f in os.listdir("."):
        if f.startswith("credentials-") and f.endswith(".json"):
            os.remove(f)

print("Done")
