#!/usr/bin/python3

import getopt
import sys

import adaptors
import databases

#
# Stop the adaptors and databases locally or in AWS
#

assert sys.version_info >= (3, 7)


def usage():
    print("Usage: stop.py [-d | -l]")
    print("-d = AWS Kubernetes/Docker")
    print("-l = Local Docker")


try:
    opts, _ = getopt.getopt(sys.argv[1:], "dlh")
except getopt.GetoptError as err:
    print("ERROR: " + err.msg + "\n")
    usage()
    sys.exit(1)

repo_db_adaptor_image = "160909222919.dkr.ecr.us-west-2.amazonaws.com/younite/younite-db-adaptor:latest"
local_db_adaptor_image = "younite/younite-db-adaptor"

namespace = "default"

local = False
demo = False
for o, _ in opts:
    if o == "-d":
        demo = True
    elif o == "-l":
        local = True
    elif o == "-h":
        usage()
        sys.exit(0)

if demo and not local:
    adaptors.stop_adaptors_aws_demo(namespace)
    databases.stop_databases_aws_demo(namespace)
elif local and not demo:
    adaptors.stop_adaptors_local(local_db_adaptor_image)
    adaptors.stop_adaptors_local(repo_db_adaptor_image)
    databases.stop_databases_local()
else:
    usage()
    sys.exit(2)
